Data Type Routines
==================

.. https://docs.scipy.org/doc/numpy/reference/routines.dtype.html

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.can_cast
   cupy.result_type
   cupy.common_type

.. csv-table::
   :align: left

   ``cupy.promote_types`` (alias of :func:`numpy.promote_types`)
   ``cupy.min_scalar_type`` (alias of :func:`numpy.min_scalar_type`)
   ``cupy.obj2sctype`` (alias of :func:`numpy.obj2sctype`)

Creating data types
-------------------

.. csv-table::
   :align: left

   ``cupy.dtype`` (alias of :class:`numpy.dtype`)
   ``cupy.format_parser`` (alias of :class:`numpy.format_parser`)

Data type information
---------------------

.. csv-table::
   :align: left

   ``cupy.finfo`` (alias of :class:`numpy.finfo`)
   ``cupy.iinfo`` (alias of :class:`numpy.iinfo`)
   ``cupy.MachAr`` (alias of :class:`numpy.MachAr`)

Data type testing
-----------------

.. csv-table::
   :align: left

   ``cupy.issctype`` (alias of :func:`numpy.issctype`)
   ``cupy.issubdtype`` (alias of :func:`numpy.issubdtype`)
   ``cupy.issubsctype`` (alias of :func:`numpy.issubsctype`)
   ``cupy.issubclass_`` (alias of :func:`numpy.issubclass_`)
   ``cupy.find_common_type`` (alias of :func:`numpy.find_common_type`)

Miscellaneous
-------------

.. csv-table::
   :align: left

   ``cupy.typename`` (alias of :func:`numpy.typename`)
   ``cupy.sctype2char`` (alias of :func:`numpy.sctype2char`)
   ``cupy.mintypecode`` (alias of :func:`numpy.mintypecode`)
